package com.playlet.system.mapper;

import java.util.List;
import com.playlet.system.domain.PlayletItemType;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 剧场列Mapper接口
 *
 * @author ruoyi
 * @date 2024-03-18
 */
public interface PlayletItemTypeMapper extends BaseMapper<PlayletItemType>
{
    /**
     * 查询剧场列
     *
     * @param id 剧场列主键
     * @return 剧场列
     */
    public PlayletItemType selectPlayletItemTypeById(Long id);

    /**
     * 查询剧场列列表
     *
     * @param playletItemType 剧场列
     * @return 剧场列集合
     */
    public List<PlayletItemType> selectPlayletItemTypeList(PlayletItemType playletItemType);

    /**
     * 新增剧场列
     *
     * @param playletItemType 剧场列
     * @return 结果
     */
    public int insertPlayletItemType(PlayletItemType playletItemType);

    /**
     * 修改剧场列
     *
     * @param playletItemType 剧场列
     * @return 结果
     */
    public int updatePlayletItemType(PlayletItemType playletItemType);

    /**
     * 删除剧场列
     *
     * @param id 剧场列主键
     * @return 结果
     */
    public int deletePlayletItemTypeById(Long id);

    /**
     * 批量删除剧场列
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePlayletItemTypeByIds(String[] ids);
}
